@@ -8,7 +8,7 @@ use URI::Escape;
 use XML::Simple;
 use Carp;
 
-our $VERSION = "0.2.3";
+our $VERSION = "0.2.5";
 
 =head1 NAME
 
@@ -72,7 +72,7 @@ sub checkimage {
 	my @links=shift;
 	$imagetextnotemp=~s/\{\{.+?\}\}//sg;
 	unless ($tag) {$imagetext=~/\{(.+?)[\}\|]/; $tag=$1||'';}
-        if ($imagetext=~/\{\{(?:Non-free|fair use|music sample)/i and $imagetextnotemp!~/(\w+\W+){25}/ and $imagetext!~/\{\{Information\W*(\w+\W+){25}/i and $imagetext!~/rationale|\{\{logo fur|\{\{Non-free use|\{\{Non-free media|\{\{Non-free image|\{\{album cover fur|\{\{Non-free fair use rationale|\{\{Historic fur|\{\{User:GeeJo\/FUR|\{\{Film cover fur|\{\{Book cover fur|\{\{[^\}]+Fair use audio|\{\{Non-free Wikimedia/i and $tag!~/C-uploaded/i) {
+        if ($imagetext=~/\{\{(?:Non-free|fair use|music sample)/i and $imagetextnotemp!~/(\w+\W+){25}/ and $imagetext!~/\{\{Information\W*(\w+\W+){25}/i and $imagetext!~/rationale|\{\{logo fur|\{\{Non-free use|\{\{Non-free media|\{\{Non-free image|\{\{album cover fur|\{\{Non-free fair use rationale|\{\{Historic fur|\{\{User:GeeJo\/FUR|\{\{Vgboxart fur|\{\{Film cover fur|\{\{Film screenshot fur|\{\{Book cover fur|\{\{[^\}]+Fair use audio|\{\{Non-free Wikimedia/i and $tag!~/C-uploaded/i) {
                 #IF this is a non-free image (indicated by a tag with a name starting with non-free, fair use, or music sample,
                 #AND the image text (excluding templates and template parameters, like {{Information}} or the rationale form) has 
                 #LESS THAN 25 words,
@@ -269,7 +269,7 @@ A simple unified opt out list. Pass a user, returns 1 if they're on the list, re
 
 sub optout {
 	my ($user)=@_;
-	if ($user=~/User:(23skidoo|TreasuryTag)/) {
+	if ($user=~/User:(23skidoo|TreasuryTag|Matt Fitzpatrick|Commdor)/) {
 		return 1;
 	} else {
 		return 0;
